Test sphinx-xml2rfc
===================

.. xml2rfc:version:: draft
   :ref_type: branch
   :ref_name: foo
   :ref_path: foo

.. xml2rfc:version:: draft
   :ref_type: branch
   :ref_name: bar
   :ref_path: bar

.. xml2rfc:diff:: draft
   :from: foo
   :to: bar
